:orphan:

:py:mod:`icclim._core.generic.threshold.threshold_templates`
============================================================

.. py:module:: icclim._core.generic.threshold.threshold_templates


Module Contents
---------------

.. py:class:: ThresholdMetadata




   TypedDict of the threshold metadata.

   Used to fill the threshold template.

   .. attribute:: long_name

      Long name of the threshold

      :type: str

   .. attribute:: short_name

      Short name of the threshold

      :type: str

   .. attribute:: standard_name

      Standard name of the threshold. Ressemble the CF convention standard names, but is not actually standard.

      :type: str


.. py:class:: ThresholdTemplateDict


.. py:class:: PercentileTemplateConfig
